package com.bonus.material.iot.service;

import java.util.List;
import com.bonus.material.iot.domain.IotMachine;

/**
 * 设备管理Service接口
 * 
 * @author xsheng
 * @date 2024-10-16
 */
public interface IIotMachineService {
    /**
     * 查询设备管理
     * 
     * @param id 设备管理主键
     * @return 设备管理
     */
    public IotMachine selectIotMachineById(Long id);

    /**
     * 查询设备管理列表
     * 
     * @param iotMachine 设备管理
     * @return 设备管理集合
     */
    public List<IotMachine> selectIotMachineList(IotMachine iotMachine);

    /**
     * 新增设备管理
     * 
     * @param iotMachine 设备管理
     * @return 结果
     */
    public int insertIotMachine(IotMachine iotMachine);

    /**
     * 修改设备管理
     * 
     * @param iotMachine 设备管理
     * @return 结果
     */
    public int updateIotMachine(IotMachine iotMachine);

    /**
     * 批量删除设备管理
     * 
     * @param ids 需要删除的设备管理主键集合
     * @return 结果
     */
    public int deleteIotMachineByIds(Long[] ids);

    /**
     * 删除设备管理信息
     * 
     * @param id 设备管理主键
     * @return 结果
     */
    public int deleteIotMachineById(Long id);
}
