package com.bonus.material.iot.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.iot.domain.IotMachine;
import com.bonus.material.iot.service.IIotMachineService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 设备管理Controller
 * 
 * @author xsheng
 * @date 2024-10-16
 */
@Api(tags = "设备管理接口")
@RestController
@RequestMapping("/iot_machine")
public class IotMachineController extends BaseController {
    @Autowired
    private IIotMachineService iotMachineService;

    /**
     * 查询设备管理列表
     */
    @ApiOperation(value = "查询设备管理列表")
    @RequiresPermissions("iot:machine:list")
    @GetMapping("/list")
    public TableDataInfo list(IotMachine iotMachine) {
        startPage();
        List<IotMachine> list = iotMachineService.selectIotMachineList(iotMachine);
        return getDataTable(list);
    }

    /**
     * 导出设备管理列表
     */
    @ApiOperation(value = "导出设备管理列表")
    @PreventRepeatSubmit
    @RequiresPermissions("iot:machine:export")
    @SysLog(title = "设备管理", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出设备管理")
    @PostMapping("/export")
    public void export(HttpServletResponse response, IotMachine iotMachine) {
        List<IotMachine> list = iotMachineService.selectIotMachineList(iotMachine);
        ExcelUtil<IotMachine> util = new ExcelUtil<IotMachine>(IotMachine.class);
        util.exportExcel(response, list, "设备管理数据");
    }

    /**
     * 获取设备管理详细信息
     */
    @ApiOperation(value = "获取设备管理详细信息")
    @RequiresPermissions("iot:machine:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(iotMachineService.selectIotMachineById(id));
    }

    /**
     * 新增设备管理
     */
    @ApiOperation(value = "新增设备管理")
    @PreventRepeatSubmit
    @RequiresPermissions("iot:machine:add")
    @SysLog(title = "设备管理", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增设备管理")
    @PostMapping
    public AjaxResult add(@RequestBody IotMachine iotMachine) {
        try {
            return toAjax(iotMachineService.insertIotMachine(iotMachine));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改设备管理
     */
    @ApiOperation(value = "修改设备管理")
    @PreventRepeatSubmit
    @RequiresPermissions("iot:machine:edit")
    @SysLog(title = "设备管理", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改设备管理")
    @PutMapping
    public AjaxResult edit(@RequestBody IotMachine iotMachine) {
        try {
            return toAjax(iotMachineService.updateIotMachine(iotMachine));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除设备管理
     */
    @ApiOperation(value = "删除设备管理")
    @PreventRepeatSubmit
    @RequiresPermissions("iot:machine:remove")
    @SysLog(title = "设备管理", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除设备管理")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(iotMachineService.deleteIotMachineByIds(ids));
    }
}
